@@ -1,30 +1,29 @@
 """Module for testing hec.duration module
 """
 
-from hec.duration import Duration
-from hec.interval import Interval
+from hec import Duration, Interval
 
 
 def test_durations() -> None:
-    for intvl in Interval.getAllCwms():
+    for intvl in Interval.get_all_cwms():
         print(intvl.name)
         if intvl.name.startswith("~") or intvl.name.endswith("Local"):
             continue
         for bop in (False, True):
-            dur = Duration.forInterval(intvl, bop)
-            print(dur, dur.name, dur.minutes, dur.isBop)
+            dur = Duration.for_interval(intvl, bop)
+            print(dur, dur.name, dur.minutes, dur.is_bop)
             if intvl.minutes == 0:
                 assert str(dur) == str(intvl)
-                assert dur.isBop
-                assert dur.isEop
+                assert dur.is_bop
+                assert dur.is_eop
             else:
                 if bop:
                     assert dur.name == f"{intvl.name}BOP"
                 else:
                     assert dur.name == intvl.name
                 assert str(dur) == str(intvl) + (":BOP" if bop else ":EOP")
-                assert dur.isBop == bop
-                assert dur.isEop == (not bop)
+                assert dur.is_bop == bop
+                assert dur.is_eop == (not bop)
             assert dur.minutes == intvl.minutes
 
 
