@@ -11,10 +11,7 @@ from zoneinfo import ZoneInfo
 import pytest
 import tzlocal
 
-from hec import hectime
-from hec.hectime import HecTime
-from hec.interval import Interval
-from hec.timespan import TimeSpan
+from hec import HecTime, Interval, TimeSpan, hectime
 
 Y, M, D, H, N, S = range(6)
 
@@ -42,44 +39,44 @@ time_data_filenames: dict[int, str] = {
 }
 
 
-# ----------------------- #
-# test hectime.addCentury #
-# ----------------------- #
+# ------------------------ #
+# test hectime.add_century #
+# ------------------------ #
 @pytest.mark.parametrize(
     "_y, _expected", dataset_from_file("resources/hectime/add_century.txt")
 )
-def test_addCentury(_y: str, _expected: str) -> None:
+def test_add_century(_y: str, _expected: str) -> None:
     y, expected = tuple(map(int, (_y, _expected)))
     if y >= 100:
         # legitimate non-2-digit years, behavior differs from Java HecTime.addCentury
-        assert hectime.addCentury(y) == y
+        assert hectime.add_century(y) == y
     else:
         # same behavior as Java HecTime.addCentury
-        assert hectime.addCentury(y) == expected
+        assert hectime.add_century(y) == expected
 
 
-# ---------------------- #
-# test hectime.cleanTime #
-# ---------------------- #
+# ----------------------- #
+# test hectime.clean_time #
+# ----------------------- #
 @pytest.mark.parametrize(
     "_time, _expected", dataset_from_file("resources/hectime/clean_times.txt")
 )
-def test_cleanTime(_time: str, _expected: str) -> None:
+def test_clean_time(_time: str, _expected: str) -> None:
     time: list[int] = eval(_time)
     expected: list[int] = eval(_expected)
-    hectime.cleanTime(time)
+    hectime.clean_time(time)
     assert time == expected
 
 
 # ------------------------------------------------ #
-# test hectime.computeNumberIntervals              #
+# test hectime.compute_number_intervals            #
 #                                                  #
 # runs 43500 tests, skip with pytest -m "not slow" #
 # or set SLOW_TEST_COVERAGE env var to < 100 to    #
 # run a random subset of the specified percentage  #
 # ------------------------------------------------ #
 INTERVALS = [
-    Interval.getAny(lambda i: i.minutes == m)
+    Interval.get_any(lambda i: i.minutes == m)
     for m in sorted(set([m for m in Interval.MINUTES.values() if m > 0]))
 ]
 if slow_test_coverage < 100:
@@ -90,12 +87,12 @@ if slow_test_coverage < 100:
 @pytest.mark.parametrize(
     "time1, time2", dataset_from_file("resources/hectime/interval_count.txt", slow=True)
 )
-def test_computeNumberIntervals(time1: str, time2: str) -> None:
+def test_compute_number_intervals(time1: str, time2: str) -> None:
     t1 = HecTime(time1)
     t2 = HecTime(time2)
     for interval in INTERVALS:
         assert interval is not None
-        count = t1.computeNumberIntervals(t2, interval)
+        count = t1.compute_number_intervals(t2, interval)
         t3 = HecTime(t1)
         t3.increment(count, interval)
         assert t3 <= t2
@@ -103,20 +100,20 @@ def test_computeNumberIntervals(time1: str, time2: str) -> None:
         assert t3 >= t2
 
 
-# ----------------------------------------------------- #
-# test hectime.convertTimeZone, HecTime.convertTimeZone #
-# ----------------------------------------------------- #
+# --------------------------------------------------------- #
+# test hectime.convert_time_zone, HecTime.convert_time_zone #
+# --------------------------------------------------------- #
 @pytest.mark.parametrize(
-    "time1, fromTz, toTz, time2",
+    "time1, from_tz, to_tz, time2",
     dataset_from_file("resources/hectime/convert_timezone.txt"),
 )
-def test_convertTimeZone(time1: str, fromTz: str, toTz: str, time2: str) -> None:
+def test_convert_time_zone(time1: str, from_tz: str, to_tz: str, time2: str) -> None:
     t = HecTime(time1)
-    hectime.convertTimeZone(t, ZoneInfo(fromTz), ZoneInfo(toTz))
-    assert t.dateAndTime(-13) == time2
+    hectime.convert_time_zone(t, ZoneInfo(from_tz), ZoneInfo(to_tz))
+    assert t.date_and_time(-13) == time2
     t = HecTime(time1)
-    t.convertTimeZone(ZoneInfo(fromTz), ZoneInfo(toTz))
-    assert t.dateAndTime(-13) == time2
+    t.convert_time_zone(ZoneInfo(from_tz), ZoneInfo(to_tz))
+    assert t.date_and_time(-13) == time2
 
 
 # ------------------------------------ #
@@ -131,7 +128,7 @@ def test_curtim() -> None:
         time.sleep(0.25)
         now = datetime.now()
     hectime.curtim(julian, minute)
-    hectime.julianToYearMonthDay(julian[0], timevals)
+    hectime.julian_to_year_month_day(julian[0], timevals)
     timevals[H], timevals[N] = divmod(minute[0], 60)
     assert timevals[:5] == [now.year, now.month, now.day, now.hour, now.minute]
     hectime.systim(julian2, timeval)
@@ -150,9 +147,9 @@ def test_curtim() -> None:
     assert diff1 == diff2
 
 
-# ---------------------------------------------- #
-# test hectime.datcln, hectime.normalizeTimeVals #
-# ---------------------------------------------- #
+# ------------------------------------------------ #
+# test hectime.datcln, hectime.normalize_time_vals #
+# ------------------------------------------------ #
 @pytest.mark.parametrize(
     "_time, _expected", dataset_from_file("resources/hectime/clean_times.txt")
 )
@@ -160,21 +157,21 @@ def test_datcln(_time: str, _expected: str) -> None:
     time: list[int] = eval(_time)
     expected: list[int] = eval(_expected)
     if len(time) == 2:
-        julianClean = [0]
-        minuteClean = [0]
-        hectime.datcln(time[0], time[1], julianClean, minuteClean)
-        assert julianClean[0] == expected[0]
-        assert minuteClean[0] == expected[1]
+        julian_clean = [0]
+        minute_clean = [0]
+        hectime.datcln(time[0], time[1], julian_clean, minute_clean)
+        assert julian_clean[0] == expected[0]
+        assert minute_clean[0] == expected[1]
     elif len(time) == 6:
-        hectime.normalizeTimeVals(time)
+        hectime.normalize_time_vals(time)
         assert time == expected
 
 
 # --------------------------------------------------------------------------- #
 # test hectime.datjul, hectime.datymd, hectime.iymdjl, hectime.jliymd,        #
 # hectime.juldat, hectime.ymddat                                              #
-# exercises hectime.parseDateTimeString, hectime.julianToYearMonthDay,        #
-# hectime.yearMonthDayToJulian                                                #
+# exercises hectime.parse_date_time_str, hectime.juilan_to_year_month_day,    #
+# hectime.year_month_day_to_julian                                            #
 # --------------------------------------------------------------------------- #
 @pytest.mark.parametrize(
     "datestr, _jul, _y, _m, _d", dataset_from_file("resources/hectime/dat_jul_ymd.txt")
@@ -196,39 +193,39 @@ def test_dat_jul_ymd(datestr: str, _jul: str, _y: str, _m: str, _d: str) -> None
     assert hectime.ymddat(ymd, 4, err) == datestr
 
 
-# --------------------------------------------- #
-# test hectime.getime and hectime.getTimeWindow #
-# --------------------------------------------- #
+# ----------------------------------------------- #
+# test hectime.getime and hectime.get_time_window #
+# ----------------------------------------------- #
 @pytest.mark.parametrize(
-    "twStr, startTime, endTime, _juls, _mins, _jule, _mine",
+    "tw_str, start_time, end_time, _juls, _mins, _jule, _mine",
     dataset_from_file("resources/hectime/time_window.txt"),
 )
-def test_getTimeWindow_getime(
-    twStr: str,
-    startTime: str,
-    endTime: str,
+def test_get_time_window__getime(
+    tw_str: str,
+    start_time: str,
+    end_time: str,
     _juls: str,
     _mins: str,
     _jule: str,
     _mine: str,
 ) -> None:
-    tStart: HecTime = HecTime()
-    tEnd: HecTime = HecTime()
+    t_start: HecTime = HecTime()
+    t_end: HecTime = HecTime()
     juls, mins, jule, mine = list(map(int, (_juls, _mins, _jule, _mine)))
-    julStart = [0]
-    minStart = [0]
-    julEnd = [0]
-    minEnd = [0]
+    jul_start = [0]
+    min_start = [0]
+    jul_end = [0]
+    min_end = [0]
     status = [0]
-    hectime.getTimeWindow(twStr, tStart, tEnd)
-    assert tStart.dateAndTime(-13) == startTime
-    assert tEnd.dateAndTime(-13) == endTime
-    hectime.getime(twStr, julStart, minStart, julEnd, minEnd, status)
+    hectime.get_time_window(tw_str, t_start, t_end)
+    assert t_start.date_and_time(-13) == start_time
+    assert t_end.date_and_time(-13) == end_time
+    hectime.getime(tw_str, jul_start, min_start, jul_end, min_end, status)
     assert status[0] == 0
-    assert julStart[0] == juls
-    assert minStart[0] == mins
-    assert julEnd[0] == jule
-    assert minEnd[0] == mine
+    assert jul_start[0] == juls
+    assert min_start[0] == mins
+    assert jul_end[0] == jule
+    assert min_end[0] == mine
 
 
 # -------------------------------------------------------------------------------------- #
@@ -249,9 +246,9 @@ def test_m_hm(_minutes: str, timestr: str) -> None:
     assert hectime.ihm2m_2("~".join(list(timestr))) == minutes
 
 
-# ------------------------------------------------------------- #
-# test hectime.idaywk, HecTime.dayOfWeek, HecTime.dayOfWeekName #
-# ------------------------------------------------------------- #
+# ------------------------------------------------------------------ #
+# test hectime.idaywk, HecTime.day_of_week, HecTime.day_of_week_name #
+# ------------------------------------------------------------------ #
 @pytest.mark.parametrize(
     "datestr, _jul, _weekday, dayname",
     dataset_from_file("resources/hectime/weekday.txt"),
@@ -262,13 +259,13 @@ def test_weekday(datestr: str, _jul: str, _weekday: str, dayname: str) -> None:
     t = HecTime(datestr)
     t.midnight_as_2400 = False
     assert hectime.idaywk(cast(list[int], t.values)) == weekday
-    assert t.dayOfWeek() == weekday
-    assert t.dayOfWeekName() == dayname
+    assert t.day_of_week() == weekday
+    assert t.day_of_week_name() == dayname
 
 
 # ------------------------------------------------ #
 # test HecTime.increment, hectime.inctim           #
-# exercises hectime.incrementTimeVals              #
+# exercises hectime.increment_time_vals            #
 #                                                  #
 # runs 63510 tests, skip with pytest -m "not slow" #
 # or set SLOW_TEST_COVERAGE env var to < 100 to    #
@@ -285,47 +282,47 @@ def test_increment(start_time: str, _interval: str, _count: str, end_time: str)
     t = HecTime(start_time)
     t2 = HecTime(t)
     t2.increment(count, interval)
-    assert t2.dateAndTime(-13) == end_time
-    intvl = Interval.getAny(lambda i: i.minutes == interval)
+    assert t2.date_and_time(-13) == end_time
+    intvl = Interval.get_any(lambda i: i.minutes == interval)
     assert intvl is not None
     t2 = HecTime(t)
     t2.increment(count, intvl)
-    assert t2.dateAndTime(-13) == end_time
+    assert t2.date_and_time(-13) == end_time
     ts = TimeSpan(str(intvl)) + timedelta(minutes=10)
     t3 = HecTime(t)
     t3.increment(count, ts)
     t4 = HecTime(end_time)
     t4 += count * timedelta(minutes=10)
     assert t3 == t4
-    startJul = t.julian()
-    startMin = t.minutesSinceMidnight()
-    endJul = [0]
-    endMin = [0]
-    hectime.inctim(interval, count, startJul, startMin, endJul, endMin)
-    assert endJul[0] == t2.julian()
-    assert endMin[0] == t2.minutesSinceMidnight()
+    start_jul = t.julian()
+    start_min = t.minutes_since_midnight()
+    end_jul = [0]
+    end_min = [0]
+    hectime.inctim(interval, count, start_jul, start_min, end_jul, end_min)
+    assert end_jul[0] == t2.julian()
+    assert end_min[0] == t2.minutes_since_midnight()
     if intvl.minutes <= Interval.MINUTES["1Week"]:
         # --------------------------------- #
         # can't use calendar info in inctim #
         # --------------------------------- #
-        intvl = Interval.getAny(lambda i: i.minutes == interval)
+        intvl = Interval.get_any(lambda i: i.minutes == interval)
         assert intvl is not None
-        endJul = [0]
-        endMin = [0]
-        hectime.inctim(intvl, count, startJul, startMin, endJul, endMin)
-        assert endJul[0] == t2.julian()
-        assert endMin[0] == t2.minutesSinceMidnight()
+        end_jul = [0]
+        end_min = [0]
+        hectime.inctim(intvl, count, start_jul, start_min, end_jul, end_min)
+        assert end_jul[0] == t2.julian()
+        assert end_min[0] == t2.minutes_since_midnight()
         ts = TimeSpan(str(intvl)) + timedelta(minutes=10)
-        endJul = [0]
-        endMin = [0]
-        hectime.inctim(ts, count, startJul, startMin, endJul, endMin)
-        assert endJul[0] == t4.julian()
-        assert endMin[0] == t4.minutesSinceMidnight()
+        end_jul = [0]
+        end_min = [0]
+        hectime.inctim(ts, count, start_jul, start_min, end_jul, end_min)
+        assert end_jul[0] == t4.julian()
+        assert end_min[0] == t4.minutes_since_midnight()
 
 
-# --------------------------------------------------- #
-# test HecTime.adjustToIntervalOffset, hectime.zofset #
-# --------------------------------------------------- #
+# ------------------------------------------------------ #
+# test HecTime.adjust_to_interval_offset, hectime.zofset #
+# ------------------------------------------------------ #
 @pytest.mark.parametrize(
     "time1, _interval, _offset, time2",
     dataset_from_file("resources/hectime/adjust_to_interval_offset.txt"),
@@ -342,12 +339,12 @@ def test_interval_offset(time1: str, _interval: str, _offset: str, time2: str) -
     t.midnight_as_2400 = False
     t.set(time1)
     jul0[0] = jul1[0] = cast(int, t.julian())
-    min0[0] = min1[0] = cast(int, t.minutesSinceMidnight())
-    computed_offset = t.getIntervalOffset(interval)
-    t.adjustToIntervalOffset(interval, offset)
-    assert t.dateAndTime(-13) == time2
+    min0[0] = min1[0] = cast(int, t.minutes_since_midnight())
+    computed_offset = t.get_interval_offset(interval)
+    t.adjust_to_interval_offset(interval, offset)
+    assert t.date_and_time(-13) == time2
     jul2[0] = cast(int, t.julian())
-    min2[0] = cast(int, t.minutesSinceMidnight())
+    min2[0] = cast(int, t.minutes_since_midnight())
     ofst[0] = -1
     hectime.zofset(jul1, min1, interval, 0, ofst)
     assert jul1 == jul0
@@ -368,18 +365,20 @@ def test_interval_offset(time1: str, _interval: str, _offset: str, time2: str) -
     assert ofst[0] == -1
 
 
-# ------------------------------ #
-# test HecTime.getIntervalOffset #
-# ------------------------------ #
+# -------------------------------- #
+# test HecTime.get_interval_offset #
+# -------------------------------- #
 @pytest.mark.parametrize(
     "timestr, _interval, _expected_offset",
     dataset_from_file("resources/hectime/interval_offset.txt"),
 )
-def test_getIntervalOffset(timestr: str, _interval: str, _expected_offset: int) -> None:
+def test_get_interval_offset(
+    timestr: str, _interval: str, _expected_offset: int
+) -> None:
     interval = int(_interval)
     expected_offset = int(_expected_offset)
     t = HecTime(timestr)
-    assert t.getIntervalOffset(interval) == expected_offset
+    assert t.get_interval_offset(interval) == expected_offset
 
 
 # ----------------------------------------------------------------------------------------- #
@@ -394,10 +393,10 @@ for granularity in hectime.GRANULARITIES:
         lines = f.read().strip().split("\n")
     for line in lines:
         parts = line.split("\t")
-        timeInt = int(parts[0])
-        timeVals = eval(parts[1])
-        int_test_data.append((ht, timeInt, timeVals))
-        list_test_data.append((ht, timeVals, timeInt))
+        time_int = int(parts[0])
+        time_vals = eval(parts[1])
+        int_test_data.append((ht, time_int, time_vals))
+        list_test_data.append((ht, time_vals, time_int))
     if slow_test_coverage < 100:
         int_test_data = random_subset(int_test_data)
         list_test_data = random_subset(list_test_data)
@@ -410,12 +409,12 @@ for granularity in hectime.GRANULARITIES:
 # run a random subset of the specified percentage  #
 # ------------------------------------------------ #
 @pytest.mark.slow
-@pytest.mark.parametrize("ht, timeint, expectedTimeVals", int_test_data)
-def test_initialize_HecTime_from_integer(
-    ht: HecTime, timeint: int, expectedTimeVals: list[int]
+@pytest.mark.parametrize("ht, timeint, expected_time_vals", int_test_data)
+def test_initialize_hectime_from_integer(
+    ht: HecTime, timeint: int, expected_time_vals: list[int]
 ) -> None:
     assert ht.set(timeint) == 0
-    assert ht.values == expectedTimeVals
+    assert ht.values == expected_time_vals
 
 
 # ------------------------------------------------ #
@@ -425,50 +424,50 @@ def test_initialize_HecTime_from_integer(
 # run a random subset of the specified percentage  #
 # ------------------------------------------------ #
 @pytest.mark.slow
-@pytest.mark.parametrize("ht, timevals, expectedTimeInt", list_test_data)
-def test_initialize_HecTime_from_list(
-    ht: HecTime, timevals: list[int], expectedTimeInt: int
+@pytest.mark.parametrize("ht, timevals, expected_time_int", list_test_data)
+def test_initialize_hectime_from_list(
+    ht: HecTime, timevals: list[int], expected_time_int: int
 ) -> None:
     assert ht.set(timevals) == 0
-    assert ht.value == expectedTimeInt
+    assert ht.value == expected_time_int
 
 
 # ------------------------------- #
 # test initializing from a string #
 # ------------------------------- #
 @pytest.mark.parametrize(
-    "_string, _timeVals2400, _timeVals0000",
+    "_string, _time_vals_2400, _time_vals_0000",
     dataset_from_file("resources/hectime/string_date_times.txt"),
 )
-def test_initialize_HecTime_from_string(
-    _string: str, _timeVals2400: str, _timeVals0000: str
+def test_initialize_hectime_from_string(
+    _string: str, _time_vals_2400: str, _time_vals_0000: str
 ) -> None:
     string = _string.strip("'\"")
-    timeVals0000 = [int(item) for item in eval(_timeVals0000)]
+    time_vals_0000 = [int(item) for item in eval(_time_vals_0000)]
     t = HecTime(hectime.SECOND_GRANULARITY)
     t.midnight_as_2400 = False
     assert t.set(string) == 0
-    assert t.values == timeVals0000
+    assert t.values == time_vals_0000
 
 
 # ---------------------- #
 # test midnight settings #
 # ---------------------- #
 @pytest.mark.parametrize(
-    "_string, _timeVals2400, _timeVals0000",
+    "_string, _time_vals_2400, _time_vals_0000",
     dataset_from_file("resources/hectime/string_date_times.txt"),
 )
 def test_midnight_settings(
-    _string: str, _timeVals2400: str, _timeVals0000: str
+    _string: str, _time_vals_2400: str, _time_vals_0000: str
 ) -> None:
-    timeVals0000 = [int(item) for item in eval(_timeVals0000)]
-    timeVals2400 = [int(item) for item in eval(_timeVals2400)]
+    time_vals_0000 = [int(item) for item in eval(_time_vals_0000)]
+    time_vals_2400 = [int(item) for item in eval(_time_vals_2400)]
     t = HecTime(hectime.SECOND_GRANULARITY)
     t.midnight_as_2400 = True
-    assert t.set(timeVals0000) == 0
-    assert t.values == timeVals2400
+    assert t.set(time_vals_0000) == 0
+    assert t.values == time_vals_2400
     t.midnight_as_2400 = False
-    assert t.values == timeVals0000
+    assert t.values == time_vals_0000
 
 
 # ------------------------- #
@@ -485,7 +484,7 @@ def test_date_time_style(_style: str, _granularity: str, _expected: str) -> None
     ht = HecTime(int(granularity))
     ht.midnight_as_2400 = False
     assert ht.set([2024, 1, 2, 3, 4, 5]) == 0
-    assert ht.dateAndTime(int(style)) == expected
+    assert ht.date_and_time(int(style)) == expected
 
 
 # ---------------------------------------------------------- #
@@ -498,11 +497,12 @@ def test_to_from_datetime() -> None:
     ht = HecTime(hectime.SECOND_GRANULARITY)
     ht.set(dt)
     assert ht.datetime() == dt
-    assert ht.atTimeZone("UTC").datetime() == dt.replace(tzinfo=ZoneInfo("UTC"))
-    assert ht.atTimeZone("US/Central").datetime() == dt.replace(
-        tzinfo=ZoneInfo("US/Central")
+    ht = ht.label_as_time_zone("UTC")
+    dt = dt.replace(tzinfo=ZoneInfo("UTC"))
+    assert ht.convert_to_time_zone("US/Central").datetime() == dt.astimezone(
+        ZoneInfo("US/Central")
     )
-    assert ht.astimezone("UTC") == dt.replace(tzinfo=ZoneInfo("US/Central")).astimezone(
+    assert ht.astimezone("UTC") == dt.astimezone(ZoneInfo("US/Central")).astimezone(
         ZoneInfo("UTC")
     )
     dt = dt.replace(tzinfo=ZoneInfo("UTC")).astimezone(ZoneInfo("US/Central"))
@@ -631,11 +631,11 @@ def test_add_subtract_compare() -> None:
     assert ht.values == [2024, 8, 16, 12, 56, 0]
     ht += HecTime(1, hectime.DAY_GRANULARITY)
     assert ht.values == [2024, 8, 17, 12, 56, 0]
-    ht.addMinutes(1)
+    ht.add_minutes(1)
     assert ht.values == [2024, 8, 17, 12, 57, 0]
-    ht.addHours(1)
+    ht.add_hours(1)
     assert ht.values == [2024, 8, 17, 13, 57, 0]
-    ht.addDays(1)
+    ht.add_days(1)
     assert ht.values == [2024, 8, 18, 13, 57, 0]
     ht += TimeSpan(days=1)
     assert ht.values == [2024, 8, 19, 13, 57, 0]
@@ -648,11 +648,11 @@ def test_add_subtract_compare() -> None:
     assert ht.values == [2024, 8, 19, 13, 57, 0]
     ht -= TimeSpan(days=1)
     assert ht.values == [2024, 8, 18, 13, 57, 0]
-    ht.subtractDays(1)
+    ht.subtract_days(1)
     assert ht.values == [2024, 8, 17, 13, 57, 0]
-    ht.subtractHours(1)
+    ht.subtract_hours(1)
     assert ht.values == [2024, 8, 17, 12, 57, 0]
-    ht.subtractMinutes(1)
+    ht.subtract_minutes(1)
     assert ht.values == [2024, 8, 17, 12, 56, 0]
     ht -= 1
     assert ht.values == [2024, 8, 17, 12, 55, 0]
@@ -679,18 +679,18 @@ def test_add_subtract_compare() -> None:
         "Spring": {
             "start": "2025-03-09T01:00:00-08:00",
             "next": "2025-03-10T02:00:00-07:00",
-            "nextLocal": "2025-03-10T01:00:00-07:00",
+            "next_local": "2025-03-10T01:00:00-07:00",
         },
         "Fall": {
             "start": "2025-11-02T01:30:00-07:00",
             "next": "2025-11-03T00:30:00-08:00",
-            "nextLocal": "2025-11-03T01:30:00-08:00",
+            "next_local": "2025-11-03T01:30:00-08:00",
         },
     }
     table = str.maketrans("-T:", "   ")
     for season in ("Spring", "Fall"):
         # addition across DST boundary
-        ht = HecTime(times[season]["start"][:19]).atTimeZone("US/Pacific")
+        ht = HecTime(times[season]["start"][:19]).label_as_time_zone("US/Pacific")
         assert str(ht) == times[season]["start"]
         assert ht.values == list(map(int, str(ht)[:19].translate(table).split()))
         ht2 = ht + 1440
@@ -725,20 +725,20 @@ def test_add_subtract_compare() -> None:
         assert str(ht3) == times[season]["start"]
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
-        ht2 = ht + Interval.getCwms("1Day")
+        ht2 = ht + Interval.get_cwms("1Day")
         assert str(ht2) == times[season]["next"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
-        ht3 = ht2 - Interval.getCwms("1Day")
+        ht3 = ht2 - Interval.get_cwms("1Day")
         assert isinstance(ht3, HecTime)
         assert str(ht3) == times[season]["start"]
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
-        ht2 = ht + Interval.getAnyCwms(
+        ht2 = ht + Interval.get_any_cwms(
             lambda i: i.minutes == 1440 and i.is_local_regular
         )
-        assert str(ht2) == times[season]["nextLocal"]
+        assert str(ht2) == times[season]["next_local"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
-        ht3 = ht2 - Interval.getAnyCwms(
+        ht3 = ht2 - Interval.get_any_cwms(
             lambda i: i.minutes == 1440 and i.is_local_regular
         )
         assert isinstance(ht3, HecTime)
@@ -787,21 +787,21 @@ def test_add_subtract_compare() -> None:
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
         ht2 = cast(HecTime, ht.clone())
-        ht2 += Interval.getCwms("1Day")
+        ht2 += Interval.get_cwms("1Day")
         assert str(ht2) == times[season]["next"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
         ht3 = cast(HecTime, ht2.clone())
-        ht3 -= Interval.getCwms("1Day")
+        ht3 -= Interval.get_cwms("1Day")
         assert isinstance(ht3, HecTime)
         assert str(ht3) == times[season]["start"]
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
         ht2 = cast(HecTime, ht.clone())
-        ht2 += Interval.getAnyCwms(lambda i: i.minutes == 1440 and i.is_local_regular)
-        assert str(ht2) == times[season]["nextLocal"]
+        ht2 += Interval.get_any_cwms(lambda i: i.minutes == 1440 and i.is_local_regular)
+        assert str(ht2) == times[season]["next_local"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
         ht3 = cast(HecTime, ht2.clone())
-        ht3 -= Interval.getAnyCwms(lambda i: i.minutes == 1440 and i.is_local_regular)
+        ht3 -= Interval.get_any_cwms(lambda i: i.minutes == 1440 and i.is_local_regular)
         assert isinstance(ht3, HecTime)
         assert str(ht3) == times[season]["start"]
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
@@ -838,20 +838,22 @@ def test_add_subtract_compare() -> None:
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
         ht2 = cast(HecTime, ht.clone())
-        ht2.increment(1, Interval.getCwms("1Day"))
+        ht2.increment(1, Interval.get_cwms("1Day"))
         assert str(ht2) == times[season]["next"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
         ht3 = cast(HecTime, ht2.clone())
-        ht3.increment(-1, Interval.getCwms("1Day"))
+        ht3.increment(-1, Interval.get_cwms("1Day"))
         assert isinstance(ht3, HecTime)
         assert str(ht3) == times[season]["start"]
         assert ht3.values == list(map(int, str(ht3)[:19].translate(table).split()))
 
         ht2 = cast(HecTime, ht.clone())
-        intvl = Interval.getAnyCwms(lambda i: i.minutes == 1440 and i.is_local_regular)
+        intvl = Interval.get_any_cwms(
+            lambda i: i.minutes == 1440 and i.is_local_regular
+        )
         assert isinstance(intvl, Interval)
         ht2.increment(1, intvl)
-        assert str(ht2) == times[season]["nextLocal"]
+        assert str(ht2) == times[season]["next_local"]
         assert ht2.values == list(map(int, str(ht2)[:19].translate(table).split()))
         ht3 = cast(HecTime, ht2.clone())
         ht3.increment(-1, intvl)
@@ -896,4 +898,4 @@ def test_string_representation() -> None:
 
 
 if __name__ == "__main__":
-    test_add_subtract_compare()
+    test_to_from_datetime()
